@@ -11,7 +11,7 @@ from torch.distributions import constraints
 from torch.distributions.transforms import SoftmaxTransform
 
 from .utils.custom_mlp import MLP, Exp
-from .utils.utils import CustomDataset, CustomDataset3, CustomDataset4, tensor_to_numpy, convert_to_tensor
+from .utils.utils import CustomDataset, CustomDataset2, CustomDataset4, tensor_to_numpy, convert_to_tensor
 
 
 import os
@@ -97,7 +97,6 @@ class SURE(nn.Module):
                  input_size: int,
                  codebook_size: int = 200,
                  cell_factor_size: int = 0,
-                 cell_factor_names: list = None,
                  supervised_mode: bool = False,
                  z_dim: int = 10,
                  z_dist: Literal['normal','studentt','laplacian','cauchy','gumbel'] = 'normal',
@@ -135,7 +134,6 @@ class SURE(nn.Module):
         self.post_layer_fct = post_layer_fct
         self.post_act_fct = post_act_fct
         self.hidden_layer_activation = hidden_layer_activation
-        self.cell_factor_names = cell_factor_names
         
         self.codebook_weights = None
 
@@ -234,18 +232,15 @@ class SURE(nn.Module):
         )
 
         if self.cell_factor_size>0:
-            self.cell_factor_effect = nn.ModuleList()
-            for i in np.arange(self.cell_factor_size):
-                self.cell_factor_effect.append(MLP(
-                    [self.z_dim+1] + hidden_sizes + [self.z_dim],
-                    activation=activate_fct,
-                    output_activation=None,
-                    post_layer_fct=post_layer_fct,
-                    post_act_fct=post_act_fct,
-                    allow_broadcast=self.allow_broadcast,
-                    use_cuda=self.use_cuda,
-                )
-                )
+            self.cell_factor_effect = MLP(
+                [self.latent_dim + self.cell_factor_size] + self.decoder_hidden_layers + [self.latent_dim],
+                activation=activate_fct,
+                output_activation=None,
+                post_layer_fct=post_layer_fct,
+                post_act_fct=post_act_fct,
+                allow_broadcast=self.allow_broadcast,
+                use_cuda=self.use_cuda,
+            )
             
         self.decoder_concentrate = MLP(
                 [self.latent_dim] + self.decoder_hidden_layers + [self.input_size],
@@ -449,13 +444,7 @@ class SURE(nn.Module):
                 zns = pyro.sample('zn', dist.Gumbel(zn_loc, zn_scale).to_event(1))
 
             if self.cell_factor_size>0:
-                #zus = self.decoder_undesired([zns,us])
-                zus = None
-                for i in np.arange(self.cell_factor_size):
-                    if i==0:
-                        zus = self.cell_factor_effect[i]([zns,us[:,i].reshape(-1,1)])
-                    else:
-                        zus = zus + self.cell_factor_effect[i]([zns,us[:,i].reshape(-1,1)])
+                zus = self.cell_factor_effect([zns,us])
                 zs = zns+zus
             else:
                 zs = zns
@@ -645,13 +634,7 @@ class SURE(nn.Module):
                     zns = pyro.sample('zn', dist.Gumbel(zn_loc, zn_scale).to_event(1), obs=embeds)
 
             if self.cell_factor_size>0:
-                #zus = self.decoder_undesired([zns,us])
-                zus = None
-                for i in np.arange(self.cell_factor_size):
-                    if i==0:
-                        zus = self.cell_factor_effect[i]([zns,us[:,i].reshape(-1,1)])
-                    else:
-                        zus = zus + self.cell_factor_effect[i]([zns,us[:,i].reshape(-1,1)])
+                zus = self.decoder_undesired([zns,us])
                 zs = zns+zus
             else:
                 zs = zns
@@ -813,42 +796,6 @@ class SURE(nn.Module):
         A = np.concatenate(A)
         return A
     
-    def _cell_move(self, xs, factor_idx, perturb):
-        zns = self.encoder_zn(xs)
-        if type(factor_idx) == str:
-            factor_idx = np.where(self.cell_factor_names==factor_idx)
-        
-        if perturb.ndim==2:
-            ms = self.cell_factor_effect[factor_idx]([zns, perturb])
-        else:
-            ms = self.cell_factor_effect[factor_idx]([zns, perturb.reshape(-1,1)])
-            
-        return ms 
-
-    def get_cell_move(self, 
-                             xs, 
-                             factor_idx,
-                             perturb,
-                             batch_size: int = 1024):
-        """
-        Return cells' changes in the latent space induced by specific perturbation of a factor
-
-        """
-        xs = self.preprocess(xs)
-        xs = convert_to_tensor(xs, device=self.get_device())
-        dataset = CustomDataset(xs)
-        dataloader = DataLoader(dataset, batch_size=batch_size, shuffle=False)
-
-        Z = []
-        with tqdm(total=len(dataloader), desc='', unit='batch') as pbar:
-            for X_batch, _ in dataloader:
-                zns = self._cell_move(X_batch, factor_idx, perturb)
-                Z.append(tensor_to_numpy(zns))
-                pbar.update(1)
-
-        Z = np.concatenate(Z)
-        return Z
-    
     def preprocess(self, xs, threshold=0):
         if self.loss_func == 'bernoulli':
             ad = sc.AnnData(xs)
@@ -1057,24 +1004,18 @@ def parse_args():
         help="the file for the record of cell-level factors",
     )
     parser.add_argument(
-        "-delta",
-        "--delta",
-        default=0.0,
+        "-bs",
+        "--batch-size",
+        default=1000,
+        type=int,
+        help="number of cells to be considered in a batch",
+    )
+    parser.add_argument(
+        "-lr",
+        "--learning-rate",
+        default=0.0001,
         type=float,
-        help="penalty weight for zero inflation loss",
-    )
-    parser.add_argument(
-        "-64",
-        "--float64",
-        action="store_true",
-        help="use double float precision",
-    )
-    parser.add_argument(
-        "--z-dist",
-        default='normal',
-        type=str,
-        choices=['normal','laplacian','studentt','cauchy'],
-        help="distribution model for latent representation",
+        help="learning rate for Adam optimizer",
     )
     parser.add_argument(
         "-cs",
@@ -1083,6 +1024,13 @@ def parse_args():
         type=int,
         help="size of vector quantization codebook",
     )
+    parser.add_argument(
+        "--z-dist",
+        default='gumbel',
+        type=str,
+        choices=['normal','laplacian','studentt','cauchy','gumbel'],
+        help="distribution model for latent representation",
+    )
     parser.add_argument(
         "-zd",
         "--z-dim",
@@ -1090,6 +1038,27 @@ def parse_args():
         type=int,
         help="size of the tensor representing the latent variable z variable",
     )
+    parser.add_argument(
+        "-likeli",
+        "--likelihood",
+        default='negbinomial',
+        type=str,
+        choices=['negbinomial', 'multinomial', 'poisson', 'bernoulli'],
+        help="specify the distribution likelihood function",
+    )
+    parser.add_argument(
+        "-zi",
+        "--zeroinflate",
+        action="store_true",
+        help="use zeroinflation",
+    )
+    parser.add_argument(
+        "-id",
+        "--inverse-dispersion",
+        default=10.0,
+        type=float,
+        help="inverse dispersion prior for negative binomial",
+    )
     parser.add_argument(
         "-hl",
         "--hidden-layers",
@@ -1123,20 +1092,6 @@ def parse_args():
         type=str,
         help="post functions for activation layers, could be none or dropout, default is 'none'",
     )
-    parser.add_argument(
-        "-id",
-        "--inverse-dispersion",
-        default=10.0,
-        type=float,
-        help="inverse dispersion prior for negative binomial",
-    )
-    parser.add_argument(
-        "-lr",
-        "--learning-rate",
-        default=0.0001,
-        type=float,
-        help="learning rate for Adam optimizer",
-    )
     parser.add_argument(
         "-dr",
         "--decay-rate",
@@ -1158,47 +1113,10 @@ def parse_args():
         help="beta-1 parameter for Adam optimizer",
     )
     parser.add_argument(
-        "-bs",
-        "--batch-size",
-        default=1000,
-        type=int,
-        help="number of cells to be considered in a batch",
-    )
-    parser.add_argument(
-        "-gp",
-        "--gate-prior",
-        default=0.6,
-        type=float,
-        help="gate prior for zero-inflated model",
-    )
-    parser.add_argument(
-        "-likeli",
-        "--likelihood",
-        default='negbinomial',
-        type=str,
-        choices=['negbinomial', 'multinomial', 'poisson', 'gaussian','lognormal'],
-        help="specify the distribution likelihood function",
-    )
-    parser.add_argument(
-        "-dirichlet",
-        "--use-dirichlet",
+        "-64",
+        "--float64",
         action="store_true",
-        help="use Dirichlet distribution over gene frequency",
-    )
-    parser.add_argument(
-        "-mass",
-        "--dirichlet-mass",
-        default=1,
-        type=float,
-        help="mass param for dirichlet model",
-    )
-    parser.add_argument(
-        "-zi",
-        "--zero-inflation",
-        default='exact',
-        type=str,
-        choices=['none','exact','inexact'],
-        help="use zero-inflated estimation",
+        help="use double float precision",
     )
     parser.add_argument(
         "--seed",
@@ -1240,29 +1158,23 @@ def main():
     input_size = xs.shape[1]
     cell_factor_size = 0 if us is None else us.shape[1]
 
-    latent_dist = args.z_dist
-
     ###########################################
     sure = SURE(
         input_size=input_size,
         cell_factor_size=cell_factor_size,
         inverse_dispersion=args.inverse_dispersion,
-        latent_dim=args.latent_dim,
+        z_dim=args.z_dim,
         hidden_layers=args.hidden_layers,
         hidden_layer_activation=args.hidden_layer_activation,
         use_cuda=args.cuda,
         config_enum=args.enum_discrete,
-        use_dirichlet=args.use_dirichlet,
-        zero_inflation=args.zero_inflation,
-        gate_prior=args.gate_prior,
-        delta=args.delta,
+        use_zeroinflate=args.zeroinflate,
         loss_func=args.likelihood,
-        dirichlet_mass=args.dirichlet_mass,
         nn_dropout=args.layer_dropout_rate,
         post_layer_fct=args.post_layer_function,
         post_act_fct=args.post_activation_function,
         codebook_size=args.codebook_size,
-        latent_dist = latent_dist,
+        z_dist = args.z_dist,
         dtype=dtype,
     )
 
